"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setActionTypes = exports.NpmActions = exports.NpmActionType = void 0;
const child_process_1 = require("child_process");
var NpmActionType;
(function (NpmActionType) {
    NpmActionType["install"] = "Install";
})(NpmActionType = exports.NpmActionType || (exports.NpmActionType = {}));
var NpmActions;
(function (NpmActions) {
    NpmActions.install = async (directory, verbose) => {
        if (!directory) {
            throw new Error(`Invalid directory information, unable to run npm install: ${directory}`);
        }
        const spawnOptions = verbose
            ? {
                cwd: directory,
                shell: true,
                stdio: 'inherit',
            }
            : {
                cwd: directory,
                // Not sure why but if this is not set the install action fails on windows
                // Something to investigate
                shell: true,
            };
        const didSucceed = (code) => `${code}` === '0';
        return new Promise((resolve, reject) => {
            const npmI = (0, child_process_1.spawn)('npm', ['install'], spawnOptions);
            npmI
                .on('close', (code) => {
                if (didSucceed(code)) {
                    resolve(`success.`);
                    return;
                }
                reject(new Error(`failed, exit code ${code}.`));
            })
                .on('error', (code) => {
                reject(new Error(`failed, exit code ${code}.`));
            });
        });
    };
})(NpmActions = exports.NpmActions || (exports.NpmActions = {}));
const setActionTypes = (plop) => {
    plop.setActionType(NpmActionType.install, async (answers, config) => {
        const { directory, verbose } = config;
        const status = await NpmActions.install(directory, verbose);
        return status; // < There is a typing issue with Plop, these need to return a string
    });
};
exports.setActionTypes = setActionTypes;
