"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.seedSelectionNormalizer = exports.seedNormalizer = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const errors_1 = require("../../errors");
const seeds_1 = require("../../seeds");
const configure_1 = require("../../seeds/configure");
const utils_1 = require("../../utils");
const seedNormalizer = async (seeds) => seeds.map((seed) => ({
    ...seed,
    configure: seed?.type === seeds_1.SeedSource.remote ? seeds_1.configureRemote : seeds_1.configureLocal,
}));
exports.seedNormalizer = seedNormalizer;
const seedSelectionNormalizer = async (inquirer, seed) => {
    if (seed.type === seeds_1.SeedSource.local && !seed.baseDir) {
        const { baseDir } = await inquirer.prompt([
            {
                name: 'baseDir',
                type: 'select-directory',
                message: `Select local seed`,
                basePath: utils_1.basePath,
            },
        ]);
        try {
            fs.accessSync(path_1.default.join(baseDir, configure_1.genxrcPath));
        }
        catch (err) {
            const errorMsg = {
                message: `Invalid seed: ${path_1.default.join(baseDir, configure_1.genxrcPath)} - not found`,
                name: 'Seed error',
            };
            (0, errors_1.errorHandler)(errorMsg);
        }
        return {
            ...seed,
            baseDir,
        };
    }
    return seed;
};
exports.seedSelectionNormalizer = seedSelectionNormalizer;
